@@ -31,12 +31,15 @@ import net.sf.jabref.remote.RemoteListener;
 
 import gnu.dtools.ritopt.*;
 import java.awt.*;
+import java.awt.event.KeyEvent;
 
 import java.io.*;
 import java.io.File;
 
 import java.util.*;
 import java.util.List;
+import java.lang.reflect.Method;
+import java.lang.reflect.InvocationTargetException;
 
 import javax.swing.*;
 import javax.swing.plaf.metal.MetalLookAndFeel;
@@ -76,14 +79,21 @@ public class JabRef {
 
     public JabRef(String[] args) {
 
-
         ths = this;
+
+        // The following two lines signal that the system proxy settings should be used:
+        System.setProperty("java.net.useSystemProxies", "true");
+        System.getProperties().put( "proxySet", "true" );
+
         JabRefPreferences prefs = JabRefPreferences.getInstance();
         Globals.prefs = prefs;
         Globals.setLanguage(prefs.get("language"), "");
                 
         Globals.importFormatReader.resetImportFormats();
         BibtexEntryType.loadCustomEntryTypes(prefs);
+        // Build the list of available export formats:
+        ExportFormats.initAllExports();
+
         // Read list(s) of journal names and abbreviations:
         //Globals.turnOnFileLogging();
 
@@ -199,27 +209,8 @@ public class JabRef {
             System.out.println(Globals.lang("Available import formats") + ":\n"
                 + importFormats);
 
-            // + ": biblioscape, bibtexml, endnote, inspec,\n\tisi, medline, ovid,
-            // ris, scifinder, sixpack, jstor, silverplatter.");
-            // To specify export formats, we need to take the custom export formats
-            // into account.
-            // So we iterate through the custom formats and add them.
-            String outFormats = ": bibtexml, docbook, endnote, harvard, html, mods, ods, oocalc, simplehtml";
-            int length = outFormats.length();
-
-            for (int i = 0; i < Globals.prefs.customExports.size(); i++) {
-                String[] format = Globals.prefs.customExports.getElementAt(i);
-
-                if ((length + format[0].length()) > 50) {
-                    outFormats = outFormats + ",\n\t" + format[0];
-                    length = format[0].length();
-                } else {
-                    outFormats = outFormats + ", " + format[0];
-                    length += (1 + format[0].length());
-                }
-            }
-
-            System.out.println(Globals.lang("Available export formats") + outFormats
+            String outFormats = ExportFormats.getConsoleExportList(70, 20, "\t");
+            System.out.println(Globals.lang("Available export formats") + ": " + outFormats
                 + ".");
             System.exit(0);
         }
@@ -377,53 +368,21 @@ public class JabRef {
                     // This signals that the latest import should be stored in the given
                     // format to the given file.
                     ParserResult pr = (ParserResult) loaded.elementAt(loaded.size() - 1);
-
-                    // We first try to find a matching custom export format.
-                    boolean foundCustom = false;
-
-                    for (int i = 0; i < Globals.prefs.customExports.size(); i++) {
-                        String[] format = Globals.prefs.customExports.getElementAt(i);
-
-                        if (format[0].equals(data[1])) {
-                            // Found the correct export format here.
-                            
-                            try {
-                                File lfFile = new File(format[1]);
-
-                                //System.out.println(lfFile.getName());
-                                String fname = (lfFile.getName().split("\\."))[0];
-                                FileActions.exportDatabase(pr.getDatabase(),
-                                    lfFile.getParent() + File.separator, fname,
-                                    new File(data[0]), pr.getEncoding());
-                                System.out.println(Globals.lang("Exporting") + ": "
-                                    + data[0]);
-                            } catch (Exception ex) {
-                                //ex.printStackTrace();
-                                System.err.println(Globals.lang("Could not export file")
-                                    + " '" + data[0] + "': " + ex.getMessage());
-                            }
-
-                            foundCustom = true;
-
-                            break;
-                        }
-                    }
-
-                    if (!foundCustom) {
+                    System.out.println(Globals.lang("Exporting") + ": " + data[0]);
+                    ExportFormat format = ExportFormats.getExportFormat(data[1]);
+                    if (format != null) {
+                        // We have an ExportFormat instance:
                         try {
-                            System.out.println(Globals.lang("Exporting") + ": " + data[0]);
-                            FileActions.performExport(pr.getDatabase(), data[1], data[0],
-                                    pr.getEncoding());
-                            //FileActions.exportDatabase(pr.getDatabase(), data[1],
-                            //    new File(data[0]), pr.getEncoding());
-                        } catch (NullPointerException ex2) {
-                            System.err.println(Globals.lang("Unknown export format")
-                                + ": " + data[1]);
+                            format.performExport(pr.getDatabase(), data[0], pr.getEncoding(), null);
                         } catch (Exception ex) {
                             System.err.println(Globals.lang("Could not export file")
                                 + " '" + data[0] + "': " + ex.getMessage());
                         }
                     }
+                    else
+                        System.err.println(Globals.lang("Unknown export format")
+                                + ": " + data[1]);
+
                 }
             } else
                 System.err.println(Globals.lang(
@@ -642,17 +601,25 @@ public class JabRef {
                         FontPolicy fixedPolicy = FontPolicies.createFixedPolicy(fontSet);
                         WindowsLookAndFeel.setFontPolicy(fixedPolicy);
                     }
-                    
+
                     //WindowsLookAndFeel plLnf = (WindowsLookAndFeel) lnf;
                 }
 
                 if (lnf != null) {
                     try {
+
                         UIManager.setLookAndFeel(lnf);
-                        
+
                         if (!Globals.ON_WIN) {
                             UIManager.put("SimpleInternalFrame.activeTitleBackground", GUIGlobals.gradientBlue);
-                            //UIManager.put("TabbedPane.selected", Color.red);
+                        }
+
+                        if (!Globals.ON_WIN && !Globals.ON_MAC) {
+                            // For Linux, add Enter as button click key:
+                            UIDefaults def = UIManager.getDefaults();
+                            InputMap im = (InputMap)def.get("Button.focusInputMap");
+                            im.put(KeyStroke.getKeyStroke(KeyEvent.VK_ENTER, 0, false), "pressed");
+                            im.put(KeyStroke.getKeyStroke(KeyEvent.VK_ENTER, 0, true), "released");
                         }
                     } catch (Throwable ex) {
                         ex.printStackTrace();
@@ -738,6 +705,9 @@ lastEdLoop:
             //Util.pr(": Showing frame");
             jrf.setVisible(true);
 
+            // TEST TEST TEST TEST TEST TEST
+            startOOPlugin(jrf);
+
             for (int i = 0; i < loaded.size(); i++) {
                 ParserResult pr = (ParserResult) loaded.elementAt(i);
                 if (Globals.prefs.getBoolean("displayKeyWarningDialogAtStartup") && pr.hasWarnings()) {
@@ -764,6 +734,34 @@ lastEdLoop:
             System.exit(0);
     }
 
+    /**
+     * Morten Alver (sept. 06): I'm adding this to run the functionality for
+     * OpenOffice integration. I'm not sure yet how to handle deployment issues,
+     * because the OO stuff requires several OO jars on the classpath, which we
+     * shouldn't distribute because OO installations already have them.
+     *
+     * To avoid introducing dependencies on these jars for the time being,
+     * I'm keeping OO "plugin" files separate, only invoking them through reflection.
+     *
+     * @param jrf The JabRefFrame.
+     */
+    private void startOOPlugin(JabRefFrame jrf) {
+
+
+        try {
+            Class c = Class.forName("net.sf.jabref.oo.OOTestPanel");
+            Method m = c.getDeclaredMethod("open",
+                    new Class[] {JabRefFrame.class});
+            Object i = c.newInstance();
+            Object r = m.invoke(i, new Object[] {jrf});
+        } catch (Exception e) {
+            // Do nothing.
+            //System.out.println("OO plugin not found.");
+            //e.printStackTrace();
+        }
+        
+    }
+
     public static ParserResult openBibFile(String name) {
         System.out.println(Globals.lang("Opening") + ": " + name);
 
