@@ -47,12 +47,11 @@ public class JabRefPreferences {
         CUSTOM_TYPE_NAME = "customTypeName_",
         CUSTOM_TYPE_REQ = "customTypeReq_",
         CUSTOM_TYPE_OPT = "customTypeOpt_",
-    CUSTOM_TAB_NAME = "customTabName_",
-    CUSTOM_TAB_FIELDS = "customTabFields_";
+        CUSTOM_TAB_NAME = "customTabName_",
+        CUSTOM_TAB_FIELDS = "customTabFields_";
 
     public String WRAPPED_USERNAME;
 
-
     Preferences prefs;
     public HashMap defaults = new HashMap(),
         keyBinds = new HashMap(),
@@ -75,47 +74,42 @@ public class JabRefPreferences {
     private Map externalFileTypes = new HashMap();
 
     // The only instance of this class:
-    private static JabRefPreferences INSTANCE = null;
+    private static JabRefPreferences singleton = null;
 
     public static JabRefPreferences getInstance() {
-    if (INSTANCE == null)
-        INSTANCE = new JabRefPreferences();
-    return INSTANCE;
-    }
+		if (singleton == null)
+			singleton = new JabRefPreferences();
+		return singleton;
+	}
 
     // The constructor is made private to enforce this as a singleton class:
     private JabRefPreferences() {
 
         prefs = Preferences.userNodeForPackage(JabRef.class);
         //Util.pr(prefs.toString());
-
+        
         if (Globals.osName.equals(Globals.MAC)) {
-            defaults.put("pdfviewer","/Applications/Preview.app");
-            defaults.put("psviewer","/Applications/Preview.app");
-            defaults.put("htmlviewer","/Applications/Safari.app");
-        }
-        else if (Globals.osName.toLowerCase().startsWith("windows")) {
-          defaults.put("pdfviewer","cmd.exe /c start /b");
-          defaults.put("psviewer","cmd.exe /c start /b");
-          defaults.put("htmlviewer","cmd.exe /c start /b");
-          defaults.put("lookAndFeel", "com.jgoodies.plaf.windows.ExtWindowsLookAndFeel");
-
-
-        }
-
-        else {
-            defaults.put("pdfviewer","acroread");
-            defaults.put("psviewer","gv");
-            defaults.put("htmlviewer","mozilla");
-            defaults.put("lookAndFeel", "com.jgoodies.plaf.plastic.Plastic3DLookAndFeel");
-
-        }
+			defaults.put("pdfviewer", "/Applications/Preview.app");
+			defaults.put("psviewer", "/Applications/Preview.app");
+			defaults.put("htmlviewer", "/Applications/Safari.app");
+		} else if (Globals.osName.toLowerCase().startsWith("windows")) {
+			defaults.put("pdfviewer", "cmd.exe /c start /b");
+			defaults.put("psviewer", "cmd.exe /c start /b");
+			defaults.put("htmlviewer", "cmd.exe /c start /b");
+			defaults.put("lookAndFeel", "com.jgoodies.plaf.windows.ExtWindowsLookAndFeel");
+		} else {
+			defaults.put("pdfviewer", "acroread");
+			defaults.put("psviewer", "gv");
+			defaults.put("htmlviewer", "mozilla");
+			defaults.put("lookAndFeel", "com.jgoodies.plaf.plastic.Plastic3DLookAndFeel");
+		}
         defaults.put("useDefaultLookAndFeel", Boolean.TRUE);
         defaults.put("lyxpipe", System.getProperty("user.home")+File.separator+".lyx/lyxpipe");
         defaults.put("posX", new Integer(0));
         defaults.put("posY", new Integer(0));
         defaults.put("sizeX", new Integer(840));
         defaults.put("sizeY", new Integer(680));
+        defaults.put("rememberWindowLocation", Boolean.TRUE);
         defaults.put("autoResizeMode", new Integer(JTable.AUTO_RESIZE_OFF));
         defaults.put("tableColorCodesOn", Boolean.TRUE);
         defaults.put("namesAsIs", Boolean.FALSE);
@@ -135,9 +129,12 @@ public class JabRefPreferences {
         defaults.put("terDescending", Boolean.FALSE);
         defaults.put("columnNames", "entrytype;author;title;year;journal;owner;timestamp;bibtexkey");
         defaults.put("columnWidths","75;280;400;60;100;100;100;100");
+        defaults.put("xmpPrivacyFilters", "pdf;timestamp;keywords;owner;note;review");
+        defaults.put("useXmpPrivacyFilter", Boolean.FALSE);
         defaults.put("numberColWidth",new Integer(GUIGlobals.NUMBER_COL_LENGTH));
         defaults.put("workingDirectory", System.getProperty("user.home"));
         defaults.put("exportWorkingDirectory", System.getProperty("user.home"));
+        defaults.put("importWorkingDirectory", System.getProperty("user.home"));        
         defaults.put("autoOpenForm", Boolean.TRUE);
         defaults.put("entryTypeFormHeightFactor", new Integer(1));
         defaults.put("entryTypeFormWidth", new Integer(1));
@@ -182,7 +179,6 @@ public class JabRefPreferences {
         defaults.put("highlightGroupsMatchingAny", Boolean.FALSE);
         defaults.put("highlightGroupsMatchingAll", Boolean.FALSE);
         defaults.put("searchPanelVisible", Boolean.FALSE);
-
         defaults.put("defaultEncoding", System.getProperty("file.encoding"));
         defaults.put("winEdtPath", "C:\\Program Files\\WinEdt Team\\WinEdt\\WinEdt.exe");
         defaults.put("latexEditorPath", "C:\\TEMP\\Led.exe");
@@ -305,6 +301,9 @@ public class JabRefPreferences {
         defaults.put("floatMarkedEntries", Boolean.TRUE);
 
         defaults.put("useNativeFileDialogOnMac", Boolean.TRUE);
+
+        defaults.put("lastUsedExport", null);
+        defaults.put("sidePaneWidth", new Integer(-1));
         
         //defaults.put("tempDir", System.getProperty("java.io.tmpdir"));
         //Util.pr(System.getProperty("java.io.tempdir"));
@@ -321,13 +320,18 @@ public class JabRefPreferences {
         WRAPPED_USERNAME = "["+get("defaultOwner")+"]";
 
         // TODO: remove temporary registering of external file types?
-        externalFileTypes.put("pdf", new ExternalFileType("PDF", "pdf", "acroread", null));
-        externalFileTypes.put("ps", new ExternalFileType("PostScript", "ps", "gs", null));
-        externalFileTypes.put("doc", new ExternalFileType("Word file", "doc", "oowriter", null));
-        externalFileTypes.put("odt", new ExternalFileType("OpenDocument text", "odt", "oowriter", null));
-
+        updateExternalFileTypes();
+        
+        String defaultExpression = "**/.*[bibtexkey].*\\\\.[extension]";
+        defaults.put(DEFAULT_REG_EXP_SEARCH_EXPRESSION_KEY, defaultExpression);
+        defaults.put(REG_EXP_SEARCH_EXPRESSION_KEY, defaultExpression);
+        defaults.put(USE_REG_EXP_SEARCH_KEY, Boolean.FALSE);
     }
-
+    
+    public static final String DEFAULT_REG_EXP_SEARCH_EXPRESSION_KEY = "defaultRegExpSearchExpression";
+    public static final String REG_EXP_SEARCH_EXPRESSION_KEY = "regExpSearchExpression";
+    public static final String USE_REG_EXP_SEARCH_KEY = "useRegExpSearch";
+    
     public boolean putBracesAroundCapitals(String fieldName) {
         return putBracesAroundCapitalsFields.contains(fieldName);
     }
@@ -438,7 +442,7 @@ public class JabRefPreferences {
         String names = get(key);
         if (names == null)
             return null;
-        //Util.pr(key+"\n"+names);
+
         StringReader rd = new StringReader(names);
         Vector arr = new Vector();
         String rs;
@@ -664,6 +668,7 @@ public class JabRefPreferences {
     }
 
     private void defineDefaultKeyBindings() {
+        defKeyBinds.put("Push to application","ctrl L");
       defKeyBinds.put("Push to LyX","ctrl L");
       defKeyBinds.put("Push to WinEdt","ctrl shift W");
       defKeyBinds.put("Push to Emacs","ctrl shift E");
@@ -736,7 +741,9 @@ public class JabRefPreferences {
         defKeyBinds.put("Abbreviate", "ctrl alt A");
         defKeyBinds.put("Unabbreviate", "ctrl alt shift A");
         defKeyBinds.put("Search IEEXplore", "F8");
-        
+        defKeyBinds.put("Fetch ArXiv.org", "shift F8");
+        defKeyBinds.put("Write XMP", "ctrl F4");
+
         //defKeyBinds.put("Select value", "ctrl B");
     }
 
@@ -813,6 +820,16 @@ public class JabRefPreferences {
 
     }
 
+    /**
+     *
+     */
+    public void updateExternalFileTypes() {
+        externalFileTypes.put("pdf", new ExternalFileType("PDF", "pdf", get("pdfviewer"), null));
+        externalFileTypes.put("ps", new ExternalFileType("PostScript", "ps", get("psviewer"), null));
+        externalFileTypes.put("doc", new ExternalFileType("Word file", "doc", "oowriter", null));
+        externalFileTypes.put("odt", new ExternalFileType("OpenDocument text", "odt", "oowriter", null));
+    }
+
     /**
      * Look up the external file type registered for this extension, if any.
      * @param extension The file extension.
@@ -898,7 +915,6 @@ public class JabRefPreferences {
      * @return true if the field should not be wrapped.
      */
     public boolean isNonWrappableField(String fieldName) {
-
         return nonWrappableFields.contains(fieldName);
     }
 }
