@@ -1,7 +1,15 @@
 
 package net.sf.jabref;
 
-
+/**
+ * A prefsTab is a component displayed in the PreferenceDialog.
+ * 
+ * It needs to extend from Component.
+ * 
+ * @author $Author: coezbek $
+ * @version $Revision: 1.5 $ ($Date: 2007/01/22 23:00:47 $)
+ *
+ */
 public interface PrefsTab {
 
     /**
@@ -31,4 +39,10 @@ public interface PrefsTab {
      */
     public boolean readyToClose();
 
+    /**
+     * Should return the localized identifier to use for the tab.
+     * 
+     * @return Identifier for the tab (for instance "General", "Appearance" or "External Files").
+     */
+    public String getTabName();  
 }
