@@ -4,9 +4,9 @@
 //  Language: Java
 //  Compiler: JDK 1.4
 //  Authors:  Egon Willighagen
-//  Version:  $Revision: 1.3 $
-//            $Date: 2006/05/23 21:25:49 $
-//            $Author: mortenalver $
+//  Version:  $Revision: 1.4 $
+//            $Date: 2006/11/11 17:11:39 $
+//            $Author: coezbek $
 //
 //  Copyright (c) Egon Willighagen
 //
@@ -24,22 +24,15 @@ package net.sf.jabref.export.layout.format;
 
 import net.sf.jabref.export.layout.LayoutFormatter;
 
-
 /**
  * Remove brackets formatter.
- *
+ * 
  * @author $author$
- * @version $Revision: 1.3 $
+ * @version $Revision: 1.4 $
  */
-public class ToLowerCase implements LayoutFormatter
-{
-    //~ Methods ////////////////////////////////////////////////////////////////
+public class ToLowerCase implements LayoutFormatter {
 
-    public String format(String fieldText)
-    {
-        return fieldText.toLowerCase();
-    }
+	public String format(String fieldText) {
+		return fieldText.toLowerCase();
+	}
 }
-///////////////////////////////////////////////////////////////////////////////
-//  END OF FILE.
-///////////////////////////////////////////////////////////////////////////////
