@@ -6,6 +6,7 @@ import net.sf.jabref.search.HitOrMissComparator;
 import net.sf.jabref.groups.EntryTableTransferHandler;
 
 import javax.swing.*;
+import javax.swing.plaf.TableUI;
 import javax.swing.table.TableCellRenderer;
 import javax.swing.table.TableModel;
 import javax.swing.table.TableColumnModel;
@@ -25,13 +26,15 @@ import java.awt.event.ActionEvent;
 import java.util.Comparator;
 
 /**
- * Created by IntelliJ IDEA.
+ * The central table which displays the bibtex entries.
+ * 
  * User: alver
  * Date: Oct 12, 2005
  * Time: 10:29:39 PM
- * To change this template use File | Settings | File Templates.
+ * 
  */
 public class MainTable extends JTable {
+	
     private MainTableFormat tableFormat;
     private SortedList sortedForMarking, sortedForTable, sortedForSearch, sortedForGrouping;
     private boolean tableColorCodes, showingFloatSearch=false, showingFloatGrouping=false;
@@ -55,7 +58,9 @@ public class MainTable extends JTable {
         updateRenderers();
     }
 
-    public MainTable(MainTableFormat tableFormat, EventList list, JabRefFrame frame) {
+
+    public MainTable(MainTableFormat tableFormat, EventList list, JabRefFrame frame,
+                     BasePanel panel) {
         super();
         this.tableFormat = tableFormat;
         // This SortedList has a Comparator controlled by the TableComparatorChooser
@@ -85,12 +90,12 @@ public class MainTable extends JTable {
         setGridColor(Globals.prefs.getColor("gridColor"));
         comparatorChooser = new MyTableComparatorChooser(this, sortedForTable,
                 TableComparatorChooser.MULTIPLE_COLUMN_KEYBOARD);
-
+        
         final EventList selected = getSelected();
 
         // enable DnD
         setDragEnabled(true);
-        TransferHandler xfer = new EntryTableTransferHandler(this, frame);
+        TransferHandler xfer = new EntryTableTransferHandler(this, frame, panel);
         setTransferHandler(xfer);
         pane.setTransferHandler(xfer);
 
@@ -516,4 +521,52 @@ public class MainTable extends JTable {
             refreshSorting();
         }*/
     }
+
+    /**
+     * Morten Alver: This override is a workaround NullPointerException when
+     * dragging stuff into the table. I found this in a forum, but have no idea
+     * why it works.
+     * @param newUI
+     */
+    public void setUI(TableUI newUI) {
+        super.setUI(newUI);
+        TransferHandler handler = getTransferHandler();
+        setTransferHandler(null);
+        setTransferHandler(handler);
+
+    }
+
+    /**
+     * Get the first comparator set up for the given column.
+     * @param index The column number.
+     * @return The Comparator, or null if none is set.
+     */
+    public Comparator getComparatorForColumn(int index) {
+        java.util.List l = comparatorChooser.getComparatorsForColumn(index);
+        return l.size() == 0 ? null : (Comparator)l.get(0);
+    }
+
+    /**
+     * Find out which column is set as sort column.
+     * @param number The position in the sort hierarchy (primary, secondary, etc.)
+     * @return The sort column number.
+     */
+    public int getSortingColumn(int number) {
+        java.util.List l = comparatorChooser.getSortingColumns();
+        if (l.size() <= number)
+            return -1;
+        else
+            return ((Integer)l.get(number)).intValue();
+    }
+
+    /**
+     * Returns the List of entries sorted by a user-selected term. This is the
+     * sorting before marking, search etc. applies.
+     *
+     * Note: The returned List must not be modified from the outside
+     * @return The sorted list of entries.
+     */
+    public SortedList getSortedForTable() {
+        return sortedForTable;
+    }
 }
